==> refcodes-cli-2.1.2-test-sources.jar: org/refcodes/cli/StackOverflowTest.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.cli;

import static org.junit.jupiter.api.Assertions.*;

import org.junit.jupiter.api.Test;

public class StackOverflowTest {

	// /////////////////////////////////////////////////////////////////////////
	// CONSTANTES:
	// /////////////////////////////////////////////////////////////////////////

	private static boolean IS_LOG_TESTS = Boolean.getBoolean( "log.tests" );

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * "java MyProgram -r opt1 -S opt2 arg1 arg2 arg3 arg4 --test -A opt3"
	 * "http://stackoverflow.com/questions/7341683/parsing-arguments-to-a-java-command-line-program"
	 *
	 * @throws UnknownArgsException the unknown args exception
	 * @throws AmbiguousArgsException the ambiguous args exception
	 * @throws SuperfluousArgsException the superfluous args exception
	 * @throws ParseArgsException the parse args exception
	 */
	@Test
	public void testParserStackOverflow1() throws UnknownArgsException, AmbiguousArgsException, SuperfluousArgsException, ParseArgsException {

		Option<String> r = new StringOption( "-r", null, "opt1", "Your description for option r with argument opt1" );
		Option<String> s = new StringOption( "-S", null, "opt2", "Your description for option S with argument opt2" );
		// Best to put operands after options to prevent them fetching away the
		// option's args:
		Operand<String> arg1 = new StringOperand( "arg1", "Your description for arg1" );
		Operand<String> arg2 = new StringOperand( "arg2", "Your description for arg2" );
		Operand<String> arg3 = new StringOperand( "arg3", "Your description for arg3" );
		Operand<String> arg4 = new StringOperand( "arg4", "Your description for arg4" );
		Flag test = new Flag( null, "--test", null, "Your description for test" );
		Option<String> a = new StringOption( "-A", null, "opt3", "Your description for option A with argument opt3" );

		ArgsSyntax theRoot;
		ArgsParser theArgsParser;

		// All arguments must be provided, else an exception is thrown:
		theRoot = new AndCondition( r, s, a, arg1, arg2, arg3, arg4, test );
		theArgsParser = new ArgsParserImpl( theRoot );
		theArgsParser.withName( "MyProgramm" );
		theArgsParser.withSyntaxNotation( SyntaxNotation.GNU_POSIX );
		theArgsParser.printUsage();
		theArgsParser.printSeparatorLn();
		theArgsParser.printOptions();
		theArgsParser.evalArgs( new String[] {
				"-r", "RRRRR", "-S", "SSSSS", "11111", "22222", "33333", "44444", "--test", "-A", "AAAAA"
		} );

		// Let's see:
		if ( IS_LOG_TESTS ) System.out.println( "r    :=" + r.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "S    :=" + s.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg1 :=" + arg1.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg2 :=" + arg2.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg3 :=" + arg3.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg4 :=" + arg4.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "test :=" + test.getValue() + "" );
		if ( IS_LOG_TESTS ) System.out.println( "A    :=" + a.getValue() );
		assertEquals( r.getValue(), "RRRRR" );
		assertEquals( s.getValue(), "SSSSS" );
		assertEquals( arg1.getValue(), "11111" );
		assertEquals( arg2.getValue(), "22222" );
		assertEquals( arg3.getValue(), "33333" );
		assertEquals( arg4.getValue(), "44444" );
		assertEquals( test.getValue(), true );
		assertEquals( a.getValue(), "AAAAA" );

	}

	/**
	 * "java MyProgram -r opt1 -S opt2 arg1 arg2 arg3 arg4 --test -A opt3"
	 * "http://stackoverflow.com/questions/7341683/parsing-arguments-to-a-java-command-line-program"
	 *
	 * @throws UnknownArgsException the unknown args exception
	 * @throws AmbiguousArgsException the ambiguous args exception
	 * @throws SuperfluousArgsException the superfluous args exception
	 * @throws ParseArgsException the parse args exception
	 */
	@Test
	public void testParserStackOverflow2() throws UnknownArgsException, AmbiguousArgsException, SuperfluousArgsException, ParseArgsException {

		Option<String> r = new StringOption( "-r", null, "opt1", "Your description for option r with argument opt1" );
		Option<String> s = new StringOption( "-S", null, "opt2", "Your description for option S with argument opt2" );
		// Best to put operands after options to prevent them fetching away the
		// option's args:
		Operand<String> arg1 = new StringOperand( "arg1", "Your description for arg1" );
		Operand<String> arg2 = new StringOperand( "arg2", "Your description for arg2" );
		Operand<String> arg3 = new StringOperand( "arg3", "Your description for arg3" );
		Operand<String> arg4 = new StringOperand( "arg4", "Your description for arg4" );
		Flag test = new Flag( null, "--test", null, "Your description for test" );
		Option<String> a = new StringOption( "-A", null, "opt3", "Your description for option A with argument opt3" );

		ArgsSyntax theRoot;
		ArgsParser theArgsParser;

		// --test is optional:

		theRoot = new AndCondition( r, s, a, arg1, arg2, arg3, arg4, new AnyCondition( test ) );
		theArgsParser = new ArgsParserImpl( theRoot );
		theArgsParser.withName( "MyProgramm" );
		theArgsParser.withSyntaxNotation( SyntaxNotation.GNU_POSIX );
		theArgsParser.printUsage();
		theArgsParser.printSeparatorLn();
		theArgsParser.printOptions();
		theArgsParser.evalArgs( new String[] {
				"-r", "RRRRR", "-S", "SSSSS", "11111", "22222", "33333", "44444", "-A", "AAAAA"
		} );
		if ( IS_LOG_TESTS ) System.out.println( "r    :=" + r.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "S    :=" + s.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg1 :=" + arg1.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg2 :=" + arg2.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg3 :=" + arg3.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg4 :=" + arg4.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "test :=" + test.getValue() + "" );
		if ( IS_LOG_TESTS ) System.out.println( "A    :=" + a.getValue() );
		assertEquals( r.getValue(), "RRRRR" );
		assertEquals( s.getValue(), "SSSSS" );
		assertEquals( arg1.getValue(), "11111" );
		assertEquals( arg2.getValue(), "22222" );
		assertEquals( arg3.getValue(), "33333" );
		assertEquals( arg4.getValue(), "44444" );
		assertEquals( test.getValue(), false );
		assertEquals( a.getValue(), "AAAAA" );

	}
}

==> refcodes-cli-2.2.1-test-sources.jar: org/refcodes/cli/StackOverflowTest.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.cli;

import static org.junit.jupiter.api.Assertions.*;

import org.junit.jupiter.api.Test;

public class StackOverflowTest {

	// /////////////////////////////////////////////////////////////////////////
	// CONSTANTES:
	// /////////////////////////////////////////////////////////////////////////

	private static boolean IS_LOG_TESTS = Boolean.getBoolean( "log.tests" );

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * "java MyProgram -r opt1 -S opt2 arg1 arg2 arg3 arg4 --test -A opt3"
	 * "http://stackoverflow.com/questions/7341683/parsing-arguments-to-a-java-command-line-program"
	 *
	 * @throws UnknownArgsException the unknown args exception
	 * @throws AmbiguousArgsException the ambiguous args exception
	 * @throws SuperfluousArgsException the superfluous args exception
	 * @throws ParseArgsException the parse args exception
	 */
	@Test
	public void testParserStackOverflow1() throws ArgsSyntaxException {

		Option<String> r = new StringOption( "-r", null, "opt1", "Your description for option r with argument opt1" );
		Option<String> s = new StringOption( "-S", null, "opt2", "Your description for option S with argument opt2" );
		// Best to put operands after options to prevent them fetching away the
		// option's args:
		Operand<String> arg1 = new StringOperand( "arg1", "Your description for arg1" );
		Operand<String> arg2 = new StringOperand( "arg2", "Your description for arg2" );
		Operand<String> arg3 = new StringOperand( "arg3", "Your description for arg3" );
		Operand<String> arg4 = new StringOperand( "arg4", "Your description for arg4" );
		Flag test = new Flag( null, "--test", null, "Your description for test" );
		Option<String> a = new StringOption( "-A", null, "opt3", "Your description for option A with argument opt3" );

		ArgsSyntax theRoot;
		ArgsParser theArgsParser;

		// All arguments must be provided, else an exception is thrown:
		theRoot = new AndCondition( r, s, a, arg1, arg2, arg3, arg4, test );
		theArgsParser = new ArgsParserImpl( theRoot );
		theArgsParser.withName( "MyProgramm" );
		theArgsParser.withSyntaxNotation( SyntaxNotation.GNU_POSIX );
		theArgsParser.printSynopsis();
		theArgsParser.printSeparatorLn();
		theArgsParser.printOptions();
		theArgsParser.evalArgs( new String[] {
				"-r", "RRRRR", "-S", "SSSSS", "11111", "22222", "33333", "44444", "--test", "-A", "AAAAA"
		} );

		// Let's see:
		if ( IS_LOG_TESTS ) System.out.println( "r    :=" + r.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "S    :=" + s.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg1 :=" + arg1.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg2 :=" + arg2.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg3 :=" + arg3.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg4 :=" + arg4.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "test :=" + test.getValue() + "" );
		if ( IS_LOG_TESTS ) System.out.println( "A    :=" + a.getValue() );
		assertEquals( r.getValue(), "RRRRR" );
		assertEquals( s.getValue(), "SSSSS" );
		assertEquals( arg1.getValue(), "11111" );
		assertEquals( arg2.getValue(), "22222" );
		assertEquals( arg3.getValue(), "33333" );
		assertEquals( arg4.getValue(), "44444" );
		assertEquals( test.getValue(), true );
		assertEquals( a.getValue(), "AAAAA" );

	}

	/**
	 * "java MyProgram -r opt1 -S opt2 arg1 arg2 arg3 arg4 --test -A opt3"
	 * "http://stackoverflow.com/questions/7341683/parsing-arguments-to-a-java-command-line-program"
	 *
	 * @throws UnknownArgsException the unknown args exception
	 * @throws AmbiguousArgsException the ambiguous args exception
	 * @throws SuperfluousArgsException the superfluous args exception
	 * @throws ParseArgsException the parse args exception
	 */
	@Test
	public void testParserStackOverflow2() throws ArgsSyntaxException {

		Option<String> r = new StringOption( "-r", null, "opt1", "Your description for option r with argument opt1" );
		Option<String> s = new StringOption( "-S", null, "opt2", "Your description for option S with argument opt2" );
		// Best to put operands after options to prevent them fetching away the
		// option's args:
		Operand<String> arg1 = new StringOperand( "arg1", "Your description for arg1" );
		Operand<String> arg2 = new StringOperand( "arg2", "Your description for arg2" );
		Operand<String> arg3 = new StringOperand( "arg3", "Your description for arg3" );
		Operand<String> arg4 = new StringOperand( "arg4", "Your description for arg4" );
		Flag test = new Flag( null, "--test", null, "Your description for test" );
		Option<String> a = new StringOption( "-A", null, "opt3", "Your description for option A with argument opt3" );

		ArgsSyntax theRoot;
		ArgsParser theArgsParser;

		// --test is optional:

		theRoot = new AndCondition( r, s, a, arg1, arg2, arg3, arg4, new AnyCondition( test ) );
		theArgsParser = new ArgsParserImpl( theRoot );
		theArgsParser.withName( "MyProgramm" );
		theArgsParser.withSyntaxNotation( SyntaxNotation.GNU_POSIX );
		theArgsParser.printSynopsis();
		theArgsParser.printSeparatorLn();
		theArgsParser.printOptions();
		theArgsParser.evalArgs( new String[] {
				"-r", "RRRRR", "-S", "SSSSS", "11111", "22222", "33333", "44444", "-A", "AAAAA"
		} );
		if ( IS_LOG_TESTS ) System.out.println( "r    :=" + r.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "S    :=" + s.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg1 :=" + arg1.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg2 :=" + arg2.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg3 :=" + arg3.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "arg4 :=" + arg4.getValue() );
		if ( IS_LOG_TESTS ) System.out.println( "test :=" + test.getValue() + "" );
		if ( IS_LOG_TESTS ) System.out.println( "A    :=" + a.getValue() );
		assertEquals( r.getValue(), "RRRRR" );
		assertEquals( s.getValue(), "SSSSS" );
		assertEquals( arg1.getValue(), "11111" );
		assertEquals( arg2.getValue(), "22222" );
		assertEquals( arg3.getValue(), "33333" );
		assertEquals( arg4.getValue(), "44444" );
		assertEquals( test.getValue(), false );
		assertEquals( a.getValue(), "AAAAA" );

	}
}
